=========
Identifai
=========


.. image:: https://img.shields.io/pypi/v/Identifai.svg
        :target: https://pypi.python.org/pypi/Identifai

.. image:: https://img.shields.io/travis/KirillKiyko/Identifai.svg
        :target: https://travis-ci.org/KirillKiyko/Identifai

.. image:: https://readthedocs.org/projects/Identifai/badge/?version=latest
        :target: https://Identifai.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/KirillKiyko/Identifai/shield.svg
     :target: https://pyup.io/repos/github/KirillKiyko/Identifai/
     :alt: Updates


Python package for Identifai API


* Free software: MIT license
* Documentation: https://Identifai.readthedocs.io.


Features
--------

* Python package for Identifai API. Uses only with API-key.

